<?php
// $Id: weblinks.admin.inc,v 1.18 2008/07/18 14:58:12 nancyw Exp $

/**
 * @file
 * Settings form.
 */

/**
 * Module settings page.
 */
function weblinks_admin_settings(&$form_state) {
  $vocabs = taxonomy_get_vocabularies('weblinks');
  if (count($vocabs) > 1) {
    $avail_vocs = array();
    foreach ($vocabs as $vid => $vocabulary) {
      $avail_vocs[$vid] = check_plain($vocabulary->name);
    }
    ksort($avail_vocs);
    $form['weblinks_nav_vocabulary'] = array(
      '#type' => 'radios',
      '#title' => t('Vocabulary to use for Weblinks'),
      '#default_value' => variable_get('weblinks_nav_vocabulary', ''),
      '#options' => $avail_vocs,
      '#required' => true,
      '#prefix' => '<div class="weblinks-radios">',
      '#suffix' => '</div><div class="clear-block"></div>',
      );
  }
  $form['weblinks_external'] = array(
    '#type' => 'radios',
    '#title' => t('Open links in a new window'),
    '#default_value' => variable_get("weblinks_external", true),
    '#options' => array(1 => 'yes', 0 => 'no'),
    '#required' => FALSE,
    '#description' => t('Recommended to keep your vistors on your site.'),
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    );

  $form['weblinks_pagedesc'] = array(
    '#type' => 'textarea',
    '#title' => t('Page information'),
    '#rows' => 5,
    '#default_value' => variable_get("weblinks_pagedesc", null),
    '#description' => t('This description will appear at the top of the links page.  It will be filtered by your default input format.'),
    '#required' => false,
    );

  $form['weblinks_simplelinks'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use Simple Links'),
    '#default_value' => variable_get('weblinks_simplelinks', false),
    '#description' => t('Enable this if you want the links to appear on the main page, otherwise, your users will have to click on the group to view the links. The depth of the links to be displayed is specified below.'),
    '#required' => false,
  );

  $form['weblinks_collapsible'] = array(
    '#type' => 'checkbox',
    '#title' => t('Make categories collapsible'),
    '#default_value' => variable_get('weblinks_collapsible', false),
    '#description' => t('Enable this if you want the categories to be collapsible on the main page.'),
    '#required' => false,
  );

  $form['weblinks_empty_text'] = array(
    '#type' => 'textarea',
    '#title' => t('Empty container text'),
    '#rows' => 2,
    '#default_value' => variable_get('weblinks_empty_text', null),
    '#description' => t('This text will appear when a container is empty. Leave it blank for no text. It will be filtered by your default input format.'),
    '#required' => false,
    );

  $sort_options = array(
    'standard' => 'Normal Drupal - by weight, sticky, created date.',
    'title' => 'Legacy - by weight and title.',
    );
  $form['weblinks_page_sort'] = array(
    '#type' => 'radios',
    '#options' => $sort_options,
    '#title' => t('Page Sort order'),
    '#default_value' => variable_get('weblinks_page_sort', 'title'),
    '#description' => t('This determines how the links page will sort the links.'),
    '#required' => false,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
  );

  $form['weblinks_urlnode'] = array(
    '#type' => 'radios',
    '#title' => t('Links lead URL or to Web Link node'),
    '#default_value' => variable_get("weblinks_urlnode", 'url'),
    '#description' => t('Most people will want to leave this as URL. Specifying "node" makes it easier to edit the links, but requires an additional click to follow the link.'),
    '#options' => array('url' => 'URL', 'node' => 'node'),
    '#required' => FALSE,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
  );

  $form['weblinks_catdesc'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display link group descriptions'),
    '#default_value' => variable_get("weblinks_catdesc", true),
    '#description' => t('Generally recommended.'),
    '#required' => FALSE,
    );

  // @TODO: why distinguish between groups and sub-groups?
  $form['weblinks_subcatdesc'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display link sub-group descriptions'),
    '#default_value' => variable_get("weblinks_subcatdesc", false),
    '#description' => t('Generally recommended if you are showing more than the top level of links..'),
    '#required' => FALSE,
  );
  $form['weblinks_linkdesc'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display individual link descriptions'),
    '#default_value' => variable_get("weblinks_linkdesc", true),
    '#description' => t('Generally recommended.'),
    '#required' => FALSE,
  );
  $form['weblinks_linkinfo'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display link information'),
    '#default_value' => variable_get("weblinks_linkinfo", true),
    '#description' => t('This displays link author, publish date, and revision date'),
    '#required' => FALSE,
  );
  $form['weblinks_nofollow'] = array(
    '#type' => 'checkbox',
    '#title' => t('Spam link deterrent'),
    '#default_value' => variable_get('weblinks_nofollow', false),
    '#description' => t('If enabled, Drupal will add rel="nofollow" to all links, as a measure to reduce the effectiveness of spam links. Note: this will also prevent valid links from being followed by search engines, therefore it is likely most effective when enabled for anonymous users.'),
    );

  // Disallow blank setting.
  $mfd_default = variable_get("weblinks_maxfrontdepth", 1);
  if (!is_numeric($mfd_default)) {
    $mfd_default = 1;
  }
  $form['weblinks_maxfrontdepth'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum group depth (front page)'),
    '#default_value' => $mfd_default,
    '#description' => t('This controls how many subcategories, if any, will display on the main links page. Blank, zero (0), and one (1) will all show only the top level.'),
    '#required' => FALSE,
    '#size' => 2,
  );

  $form['weblinks_maxdepth'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum group depth'),
    '#default_value' => variable_get("weblinks_maxdepth", true),
    '#description' => t('This controls how many subcategories, if any, will display on other links pages.'),
    '#required' => FALSE,
    '#size' => 2,
  );
  $form['weblinks_clickthru'] = array(
    '#type' => 'textfield',
    '#title' => t('User click through'),
    '#default_value' => variable_get("weblinks_clickthru", NULL),
    '#description' => t('How many clicks a user can make before all the menus are automatically expanded. Leave blank if you do not want to set a limit.'),
    '#required' => FALSE,
    '#size' => 2,
  );

  $form['categories'] = array(
    '#type' => 'fieldset',
    '#title' => t('group settings'),
    '#collapsible' => true,
    '#collapsed' => false,
  );
  // Get the weblinks categories to add to the blogroll
  $result = db_query('SELECT tid, name FROM {term_data} WHERE vid = %d ORDER BY weight ASC, name ASC', _weblinks_get_vocid());

  while ($row = db_fetch_object($result)) {
    // Set which link categories get displayed on the links page

    $form['categories'][$row->tid] = array(
      '#type' => 'fieldset',
      '#title' => $row->name,
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );

    $form['categories'][$row->tid]['weblinks_page_'. $row->tid] = array(
      '#type' => 'checkbox',
      '#title' => $row->name,
      '#default_value' => variable_get('weblinks_page_'. $row->tid, 1),
      '#required' => FALSE,
      '#description' => t('Check to enable this group to display on the main weblinks page.'),
    );

    // Set the maximum number of links to display for each group
    $form['categories'][$row->tid]['weblinks_maxdisp_'. $row->tid] = array(
      '#type' => 'textfield',
      '#title' => t('Maximum links to display'),
      '#default_value' => variable_get('weblinks_maxdisp_'. $row->tid, NULL),
      '#size' => 2,
      '#required' => FALSE,
      '#description' => t('Leave blank if you would not like to limit the number of links displayed'),
    );
  }
  return system_settings_form($form);
}
